| Title: | The LIC for Distributed Cosine Regression Analysis |
|---|---|
| Description: | This comprehensive framework for periodic time series modeling is designated as "CLIC" (The LIC for Distributed Cosine Regression Analysis) analysis. It is predicated on the assumption that the underlying data exhibits complex periodic structures beyond simple harmonic components. The philosophy of the method is articulated in Guo G. (2020) <doi:10.1080/02664763.2022.2053949>. |
| Authors: | Guangbao Guo [aut, cre] (ORCID: <https://orcid.org/0000-0002-4115-6218>), Pengbo Kong [aut] |
| Maintainer: | Guangbao Guo <[email protected]> |
| License: | MIT + file LICENSE |
| Version: | 0.1 |
| Built: | 2026-05-25 09:12:34 UTC |
| Source: | https://github.com/cran/CLIC |
Caculate the estimators of beta on the A-opt and D-opt
beta_AD(K = K, nk = nk, alpha = alpha, X = X, y = y)beta_AD(K = K, nk = nk, alpha = alpha, X = X, y = y)
K |
is the number of subsets |
nk |
is the length of subsets |
alpha |
is the significance level |
X |
is the observation matrix |
y |
is the response vector |
A list containing:
betaA |
The estimator of beta on the A-opt. |
betaD |
The estimator of beta on the D-opt. |
Guo, G., Song, H. & Zhu, L. The COR criterion for optimal subset selection in distributed estimation. Statistics and Computing, 34, 163 (2024). doi:10.1007/s11222-024-10471-z
Guo, G., Sun, Y., Qian, G., & Wang, Q. (2022). LIC criterion for optimal subset selection in distributed interval estimation. Journal of Applied Statistics, 50(9), 1900-1920. doi:10.1080/02664763.2022.2053949.
Chang, D., Guo, G. (2024). LIC: An R package for optimal subset selection for distributed data. SoftwareX, 28, 101909.
Jing, G., & Guo, G. (2025). TLIC: An R package for the LIC for T distribution regression analysis. SoftwareX, 30, 102132.
Chang, D., & Guo, G. (2025). Research on Distributed Redundant Data Estimation Based on LIC. IAENG International Journal of Applied Mathematics, 55(1), 1-6.
Gao, H., & Guo, G. (2025). LIC for Distributed Skewed Regression. IAENG International Journal of Applied Mathematics, 55(9), 2925-2930.
Zhang, C., & Guo, G. (2025). The optimal subset estimation of distributed redundant data. IAENG International Journal of Applied Mathematics, 55(2), 270–277.
Jing, G., & Guo, G. (2025). Student LIC for distributed estimation. IAENG International Journal of Applied Mathematics, 55(3), 575–581.
Liu, Q., & Guo, G. (2025). Distributed estimation of redundant data. IAENG International Journal of Applied Mathematics, 55(2), 332–337.
p=6;n=1000;K=2;nk=200;alpha=0.05;sigma=1 e=rnorm(n,0,sigma); beta=c(sort(c(runif(p,0,1)))); data=c(rnorm(n*p,5,10));X=matrix(data, ncol=p); y=X%*%beta+e; beta_AD(K=K,nk=nk,alpha=alpha,X=X,y=y)p=6;n=1000;K=2;nk=200;alpha=0.05;sigma=1 e=rnorm(n,0,sigma); beta=c(sort(c(runif(p,0,1)))); data=c(rnorm(n*p,5,10));X=matrix(data, ncol=p); y=X%*%beta+e; beta_AD(K=K,nk=nk,alpha=alpha,X=X,y=y)
Caculate the estimator of beta on the COR
beta_cor(K = K, nk = nk, alpha = alpha, X = X, y = y)beta_cor(K = K, nk = nk, alpha = alpha, X = X, y = y)
K |
is the number of subsets |
nk |
is the length of subsets |
alpha |
is the significance level |
X |
is the observation matrix |
y |
is the response vector |
A list containing:
betaC |
The estimator of beta on the COR. |
Guo, G., Song, H. & Zhu, L. The COR criterion for optimal subset selection in distributed estimation. Statistics and Computing, 34, 163 (2024). doi:10.1007/s11222-024-10471-z
Guo, G., Sun, Y., Qian, G., & Wang, Q. (2022). LIC criterion for optimal subset selection in distributed interval estimation. Journal of Applied Statistics, 50(9), 1900-1920. doi:10.1080/02664763.2022.2053949.
Chang, D., Guo, G. (2024). LIC: An R package for optimal subset selection for distributed data. SoftwareX, 28, 101909.
Jing, G., & Guo, G. (2025). TLIC: An R package for the LIC for T distribution regression analysis. SoftwareX, 30, 102132.
Chang, D., & Guo, G. (2025). Research on Distributed Redundant Data Estimation Based on LIC. IAENG International Journal of Applied Mathematics, 55(1), 1-6.
Gao, H., & Guo, G. (2025). LIC for Distributed Skewed Regression. IAENG International Journal of Applied Mathematics, 55(9), 2925-2930.
Zhang, C., & Guo, G. (2025). The optimal subset estimation of distributed redundant data. IAENG International Journal of Applied Mathematics, 55(2), 270–277.
Jing, G., & Guo, G. (2025). Student LIC for distributed estimation. IAENG International Journal of Applied Mathematics, 55(3), 575–581.
Liu, Q., & Guo, G. (2025). Distributed estimation of redundant data. IAENG International Journal of Applied Mathematics, 55(2), 332–337.
p=6;n=1000;K=2;nk=200;alpha=0.05;sigma=1 e=rnorm(n,0,sigma); beta=c(sort(c(runif(p,0,1)))); data=c(rnorm(n*p,5,10));X=matrix(data, ncol=p); y=X%*%beta+e; beta_cor(K=K,nk=nk,alpha=alpha,X=X,y=y)p=6;n=1000;K=2;nk=200;alpha=0.05;sigma=1 e=rnorm(n,0,sigma); beta=c(sort(c(runif(p,0,1)))); data=c(rnorm(n*p,5,10));X=matrix(data, ncol=p); y=X%*%beta+e; beta_cor(K=K,nk=nk,alpha=alpha,X=X,y=y)
This cerr function generates a dataset with a specified number of observations and predictors, along with a response vector that has an error term sampled from cosine-based distributions on [-pi/2, pi/2].
cerr(n, nr, p, dist_type, ...)cerr(n, nr, p, dist_type, ...)
n |
is the number of observations |
nr |
is the number of observations with a different error distribution segment (the second block) |
p |
is the dimension of the observation |
dist_type |
is the cosine-based sampler to use:
|
... |
is additional arguments (reserved for compatibility; not used) |
X,Y,e
Guo, G., Song, H. & Zhu, L. The COR criterion for optimal subset selection in distributed estimation. Statistics and Computing, 34, 163 (2024). doi:10.1007/s11222-024-10471-z
Guo, G., Sun, Y., Qian, G., & Wang, Q. (2022). LIC criterion for optimal subset selection in distributed interval estimation. Journal of Applied Statistics, 50(9), 1900-1920. doi:10.1080/02664763.2022.2053949.
Chang, D., Guo, G. (2024). LIC: An R package for optimal subset selection for distributed data. SoftwareX, 28, 101909.
Jing, G., & Guo, G. (2025). TLIC: An R package for the LIC for T distribution regression analysis. SoftwareX, 30, 102132.
Chang, D., & Guo, G. (2025). Research on Distributed Redundant Data Estimation Based on LIC. IAENG International Journal of Applied Mathematics, 55(1), 1-6.
Gao, H., & Guo, G. (2025). LIC for Distributed Skewed Regression. IAENG International Journal of Applied Mathematics, 55(9), 2925-2930.
Zhang, C., & Guo, G. (2025). The optimal subset estimation of distributed redundant data. IAENG International Journal of Applied Mathematics, 55(2), 270–277.
Jing, G., & Guo, G. (2025). Student LIC for distributed estimation. IAENG International Journal of Applied Mathematics, 55(3), 575–581.
Liu, Q., & Guo, G. (2025). Distributed estimation of redundant data. IAENG International Journal of Applied Mathematics, 55(2), 332–337.
set.seed(12) data <- cerr(n = 1200, nr = 200, p = 5, dist_type = "cosine_random") str(data)set.seed(12) data <- cerr(n = 1200, nr = 200, p = 5, dist_type = "cosine_random") str(data)
The CLIC function builds on the LIC function by introducing the assumption that the error term follows a cosine_random distribution, thereby enhancing the length and information optimisation criterion.
CLIC(X, Y, alpha = 0.05, K = 10, nk = NULL, dist_type = "cosine_random")CLIC(X, Y, alpha = 0.05, K = 10, nk = NULL, dist_type = "cosine_random")
X |
is a design matrix |
Y |
is a random response vector of observed values |
alpha |
is the significance level |
K |
is the number of subsets |
nk |
is the sample size of subsets |
dist_type |
is the type where the error term obeys a cosine_random distribution |
MUopt, Bopt, MAEMUopt, MSEMUopt, opt, Yopt
Guo, G., Song, H. & Zhu, L. The COR criterion for optimal subset selection in distributed estimation. Statistics and Computing, 34, 163 (2024). doi:10.1007/s11222-024-10471-z
Guo, G., Sun, Y., Qian, G., & Wang, Q. (2022). LIC criterion for optimal subset selection in distributed interval estimation. Journal of Applied Statistics, 50(9), 1900-1920. doi:10.1080/02664763.2022.2053949.
Chang, D., Guo, G. (2024). LIC: An R package for optimal subset selection for distributed data. SoftwareX, 28, 101909.
Jing, G., & Guo, G. (2025). TLIC: An R package for the LIC for T distribution regression analysis. SoftwareX, 30, 102132.
Chang, D., & Guo, G. (2025). Research on Distributed Redundant Data Estimation Based on LIC. IAENG International Journal of Applied Mathematics, 55(1), 1-6.
Gao, H., & Guo, G. (2025). LIC for Distributed Skewed Regression. IAENG International Journal of Applied Mathematics, 55(9), 2925-2930.
Zhang, C., & Guo, G. (2025). The optimal subset estimation of distributed redundant data. IAENG International Journal of Applied Mathematics, 55(2), 270–277.
Jing, G., & Guo, G. (2025). Student LIC for distributed estimation. IAENG International Journal of Applied Mathematics, 55(3), 575–581.
Liu, Q., & Guo, G. (2025). Distributed estimation of redundant data. IAENG International Journal of Applied Mathematics, 55(2), 332–337.
set.seed(12) n <- 1200 nr <- 200 p <- 5 data <- cerr(n, nr, p, dist_type = "cosine_random") CLIC(data$X, data$Y, alpha = 0.05, K = 10, nk = n / 10, dist_type = "cosine_random")set.seed(12) n <- 1200 nr <- 200 p <- 5 data <- cerr(n, nr, p, dist_type = "cosine_random") CLIC(data$X, data$Y, alpha = 0.05, K = 10, nk = n / 10, dist_type = "cosine_random")
Calculate the LIC estimator based on A-optimal and D-optimal criterion
LICnew(X, Y, alpha, K, nk)LICnew(X, Y, alpha, K, nk)
X |
A matrix of observations (design matrix) with size n x p |
Y |
A vector of responses with length n |
alpha |
The significance level for confidence intervals |
K |
The number of subsets to consider |
nk |
The size of each subset |
A list containing:
E5 |
The LIC estimator based on A-optimal and D-optimal criterion. |
Guo, G., Song, H. & Zhu, L. The COR criterion for optimal subset selection in distributed estimation. Statistics and Computing, 34, 163 (2024). doi:10.1007/s11222-024-10471-z
Guo, G., Sun, Y., Qian, G., & Wang, Q. (2022). LIC criterion for optimal subset selection in distributed interval estimation. Journal of Applied Statistics, 50(9), 1900-1920. doi:10.1080/02664763.2022.2053949.
Chang, D., Guo, G. (2024). LIC: An R package for optimal subset selection for distributed data. SoftwareX, 28, 101909.
Jing, G., & Guo, G. (2025). TLIC: An R package for the LIC for T distribution regression analysis. SoftwareX, 30, 102132.
Chang, D., & Guo, G. (2025). Research on Distributed Redundant Data Estimation Based on LIC. IAENG International Journal of Applied Mathematics, 55(1), 1-6.
Gao, H., & Guo, G. (2025). LIC for Distributed Skewed Regression. IAENG International Journal of Applied Mathematics, 55(9), 2925-2930.
Zhang, C., & Guo, G. (2025). The optimal subset estimation of distributed redundant data. IAENG International Journal of Applied Mathematics, 55(2), 270–277.
Jing, G., & Guo, G. (2025). Student LIC for distributed estimation. IAENG International Journal of Applied Mathematics, 55(3), 575–581.
Liu, Q., & Guo, G. (2025). Distributed estimation of redundant data. IAENG International Journal of Applied Mathematics, 55(2), 332–337.
p = 6; n = 1000; K = 2; nk = 200; alpha = 0.05; sigma = 1 e = rnorm(n, 0, sigma); beta = c(sort(c(runif(p, 0, 1)))); data = c(rnorm(n * p, 5, 10)); X = matrix(data, ncol = p); Y = X %*% beta + e; LICnew(X = X, Y = Y, alpha = alpha, K = K, nk = nk)p = 6; n = 1000; K = 2; nk = 200; alpha = 0.05; sigma = 1 e = rnorm(n, 0, sigma); beta = c(sort(c(runif(p, 0, 1)))); data = c(rnorm(n * p, 5, 10)); X = matrix(data, ncol = p); Y = X %*% beta + e; LICnew(X = X, Y = Y, alpha = alpha, K = K, nk = nk)